@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 use strict;
 use warnings;
@@ -23,7 +23,6 @@ use Number::Bytes::Human qw( format_bytes parse_bytes );
 use File::Temp qw( tempdir );
 
 route_doc upload   => "<filename>";
-route_doc content  => "<filename> <md5>";
 route_doc download => "<filename> <md5> [dir]";
 route_doc remove   => "<filename> <md5>";
 
@@ -69,6 +68,11 @@ sub new {
     my $self = shift->SUPER::new(@_);
     $self->client->max_redirects(30);
     $self->client->connect_timeout(30);
+    $self->client->on(start => sub {
+      # tx
+      $_[1]->req->headers->header('X-Yars-Skip-Verify' => 'on');
+      $_[1]->res->max_message_size(parse_bytes($self->_config->max_message_size_client(default => 53687091200)));
+    });
     return $self;
 }
 
@@ -155,10 +159,8 @@ sub download {
             $url->path("/file/$filename/$md5");
         }
         TRACE "GET $url";
-        my $tx = $self->client->build_tx(GET => $url, { "Connection" => "Close", "Accept-Encoding" => "gzip" } );
+        my $tx = $self->client->get($url => { "Connection" => "Close", "Accept-Encoding" => "gzip" });
         # TODO: set timeout for mojo 4.0
-        $tx->res->max_message_size(parse_bytes($self->_config->max_message_size_client(default => 53687091200)));
-        $self->client->start($tx);
         $self->res($tx->res);
         $self->tx($tx);
         my $res = $tx->success or do {
@@ -452,7 +454,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -523,6 +525,8 @@ Contributors:
 
 Brian Duggan
 
+Curt Tilmes
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
