@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 
 use strict;
@@ -69,18 +69,39 @@ sub _get {
           || _redirect_to_remote_stash( $c, $filename, $md5 )
           || $c->reply->not_found;
     };
-    my $computed = digest_file_hex("$dir/$filename",'MD5');
-    unless ($computed eq $md5) {
-        WARN "Content mismatch, possible disk corruption ($filename), $md5 != $computed";
-        return $c->render(text => "content-mismatch", status => 500);
+
+    if($c->config->download_md5_verify(default => 1) || !$c->req->headers->header('X-Yars-Skip-Verify')) {
+        my $computed = digest_file_hex("$dir/$filename",'MD5');
+        unless($computed eq $md5) {
+            WARN "Content mismatch, possible disk corruption ($filename), $md5 != $computed";
+            return $c->render(text => "content-mismatch", status => 500);
+        }
     }
-    my $b64 = $c->tools->hex2b64($computed);
-    $c->res->headers->add("Content-MD5", $b64);
+
+    if ($c->req->headers->header('X-Yars-Use-X-Accel')) {
+        return _x_accel_redirect($c, "$dir/$filename", $md5);
+    }
+
+    $c->res->headers->add("Content-MD5", $c->tools->hex2b64($md5));
     $c->app->static->paths([$dir])->serve($c,$filename);
     _set_static_headers($c,"$dir/$filename");
     $c->rendered;
 };
 
+sub _x_accel_redirect
+{
+    my ($c, $localfile, $md5) = @_;
+
+    my $b64 = $c->tools->hex2b64($md5);
+    $c->res->headers->add("Content-MD5", $b64);
+    my $types = $c->app->types;
+    my $type  = $localfile =~ /\.(\w+)$/ ? $types->type($1) : undef;
+    $c->res->headers->content_type($type || $types->type('bin'));
+    $c->res->headers->add('X-Accel-Redirect', "/static$localfile");
+
+    return $c->render(status => 200, text => '');
+}
+
 sub _set_static_headers {
     # Based on Mojolicious::Static.  Probably should support if-modified..?
     my $c = shift;
@@ -96,6 +117,8 @@ sub _set_static_headers {
     return 1;
 }
 
+
+
 sub _head {
     my $c        = shift;
     my $filename = $c->stash("filename");
@@ -131,12 +154,20 @@ sub _get_from_local_stash {
     # If this is stashed locally, serve it and return true.
     # Otherwise return false.
     my $dir = $c->tools->local_stashed_dir($filename,$md5) or return 0;
-    my $computed = digest_file_hex("$dir/$filename",'MD5');
-    unless ($computed eq $md5) {
-        WARN "Content mismatch, possible disk corruption for stashed file ($filename), $md5 != $computed";
-        return 0;
+
+    if($c->config->download_md5_verify(default => 1) || !$c->req->headers->header('X-Yars-Skip-Verify')) {
+        my $computed = digest_file_hex("$dir/$filename",'MD5');
+        unless($computed eq $md5) {
+            WARN "Content mismatch, possible disk corruption ($filename), $md5 != $computed";
+            return $c->render(text => "content-mismatch", status => 500);
+        }
     }
-    $c->res->headers->add("Content-MD5", $c->tools->hex2b64($computed));
+
+    if ($c->req->headers->header('X-Yars-Use-X-Accel')) {
+        return _x_accel_redirect($c, "$dir/$filename", $md5);
+    }
+
+    $c->res->headers->add("Content-MD5", $c->tools->hex2b64($md5));
     $c->app->static->paths([$dir])->serve($c,$filename);
     $c->rendered;
     return 1;
@@ -628,18 +659,32 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.11
+version 1.12
+
+=head1 SYNOPSIS
+
+ % curl http://localhost:9001/file/764efa883dda1e11db47671c4a3bbd9e/test_file1
+
+=head1 DESCRIPTION
+
+This document provides information on the Yars specific REST API (the HTTP "routes") provided
+by Yars servers.  For a Perl interface to this API, see L<Yars::Client>.  For a command line
+interface see L<yarsclient>.  For the generic L<Clustericious> REST API that comes with all
+L<Clustericious> services, see L<Clustericious::RouteBuilder::Common>.
 
 =head1 ROUTES
 
 =head2 GET /
 
-Get a welcome message.
+Get a welcome message.  This is usually simply the text string "welcome to Yars".
 
 =head2 GET /file/#filename/:md5, GET /:md5/#filename
 
 Retrieve a file with the given name and md5.
 
+You can also make a HEAD request on the same route to determine if the
+file is available without making the yars server send the file.
+
 =head2 PUT /file/#filename/#md5
 
 PUT a file with the given name and md5.
@@ -684,7 +729,7 @@ Find the disk usage per bucket.
 
 =head1 SEE ALSO
 
-L<Yars>, L<Yars::Client>
+L<Yars>, L<Yars::Client>, L<yarsclient>, L<Clustericious>
 
 =head1 AUTHOR
 
@@ -696,6 +741,8 @@ Contributors:
 
 Brian Duggan
 
+Curt Tilmes
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
