@@ -23,9 +23,8 @@ use Mojo::UserAgent;
 use File::Spec;
 use Yars::Util qw( format_tx_error );
 
-
 # ABSTRACT: various utility functions dealing with servers, hosts, etc
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 
 sub new
@@ -437,11 +436,15 @@ Yars::Tools - various utility functions dealing with servers, hosts, etc
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 DESCRIPTION
 
-Just some useful functions here.
+This module is largely used internally by L<Yars>.  Documentation for some of
+its capabilities are provided here for the understanding of how the rest of
+the L<Yars> server works, but they should not be considered to be a public
+interface and they may change in the future, though probably not for a good
+reason.
 
 =head1 FUNCTIONS
 
@@ -573,6 +576,8 @@ Contributors:
 
 Brian Duggan
 
+Curt Tilmes
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
